Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/trunk]: src/usr.bin/error fix various typos, mainly in comments.



details:   https://anonhg.NetBSD.org/src/rev/875c577fb8c9
branches:  trunk
changeset: 1027580:875c577fb8c9
user:      andvar <andvar%NetBSD.org@localhost>
date:      Sun Dec 12 13:05:13 2021 +0000

description:
fix various typos, mainly in comments.

diffstat:

 sys/arch/atari/atari/atari_init.c       |   8 ++++----
 sys/arch/evbarm/stand/boot2440/dm9000.c |   4 ++--
 sys/dev/audio/audio.c                   |   6 +++---
 sys/dev/ic/isp.c                        |  14 +++++++-------
 sys/dev/ic/isp_target.c                 |  10 +++++-----
 sys/dev/ic/isp_tpublic.h                |   6 +++---
 sys/dev/pci/if_bnxreg.h                 |   4 ++--
 sys/dev/sbus/bereg.h                    |   4 ++--
 sys/net/if_slvar.h                      |   4 ++--
 usr.bin/error/main.c                    |   6 +++---
 10 files changed, 33 insertions(+), 33 deletions(-)

diffs (297 lines):

diff -r d323bbd451eb -r 875c577fb8c9 sys/arch/atari/atari/atari_init.c
--- a/sys/arch/atari/atari/atari_init.c Sun Dec 12 11:18:46 2021 +0000
+++ b/sys/arch/atari/atari/atari_init.c Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: atari_init.c,v 1.102 2021/08/17 22:00:27 andvar Exp $  */
+/*     $NetBSD: atari_init.c,v 1.103 2021/12/12 13:05:13 andvar Exp $  */
 
 /*
  * Copyright (c) 1995 Leo Weppelman
@@ -33,7 +33,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: atari_init.c,v 1.102 2021/08/17 22:00:27 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: atari_init.c,v 1.103 2021/12/12 13:05:13 andvar Exp $");
 
 #include "opt_ddb.h"
 #include "opt_mbtype.h"
@@ -698,7 +698,7 @@
 
 #if defined(_MILANHW_)
 /*
- * Probe and return available memory size in MB at specfied address.
+ * Probe and return available memory size in MB at specified address.
  * The first slot SIMM have at least 16MB, so check if it has 32 or 64 MB.
  *
  * Note it seems Milan does not generate bus errors on accesses against
@@ -762,7 +762,7 @@
 }
 
 /*
- * Probe and return available memory size in MB at specfied address.
+ * Probe and return available memory size in MB at specified address.
  * The rest slot could be empty so check all possible size.
  */
 static u_int
diff -r d323bbd451eb -r 875c577fb8c9 sys/arch/evbarm/stand/boot2440/dm9000.c
--- a/sys/arch/evbarm/stand/boot2440/dm9000.c   Sun Dec 12 11:18:46 2021 +0000
+++ b/sys/arch/evbarm/stand/boot2440/dm9000.c   Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: dm9000.c,v 1.3 2017/03/29 09:04:35 msaitoh Exp $ */
+/* $NetBSD: dm9000.c,v 1.4 2021/12/12 13:05:13 andvar Exp $ */
 
 /*-
  * Copyright (c) 2012 The NetBSD Foundation, Inc.
@@ -70,7 +70,7 @@
 #define  RCR_DIS_CRC   0x10    /* discard CRC error Rx frame */
 #define  RCR_ALL       0x08    /* accept MCAST frames */
 #define  RCR_RUNT      0x04    /* accept runt Rx frame */
-#define  RCR_PRMSC     0x02    /* promiscous */
+#define  RCR_PRMSC     0x02    /* promiscuous */
 #define  RCR_RXEN      0x01    /* enable frame reception */
 #define RSR    0x06            /* RX status */
 #define  RSR_MF                (1<<6)  /* bcast/mcast frame found */
diff -r d323bbd451eb -r 875c577fb8c9 sys/dev/audio/audio.c
--- a/sys/dev/audio/audio.c     Sun Dec 12 11:18:46 2021 +0000
+++ b/sys/dev/audio/audio.c     Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: audio.c,v 1.112 2021/12/10 20:36:03 andvar Exp $       */
+/*     $NetBSD: audio.c,v 1.113 2021/12/12 13:05:13 andvar Exp $       */
 
 /*-
  * Copyright (c) 2008 The NetBSD Foundation, Inc.
@@ -138,7 +138,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: audio.c,v 1.112 2021/12/10 20:36:03 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: audio.c,v 1.113 2021/12/12 13:05:13 andvar Exp $");
 
 #ifdef _KERNEL_OPT
 #include "audio.h"
@@ -7314,7 +7314,7 @@
 }
 
 /*
- * Change water marks for playback track if specfied.
+ * Change water marks for playback track if specified.
  */
 static void
 audio_track_setinfo_water(audio_track_t *track, const struct audio_info *ai)
diff -r d323bbd451eb -r 875c577fb8c9 sys/dev/ic/isp_target.c
--- a/sys/dev/ic/isp_target.c   Sun Dec 12 11:18:46 2021 +0000
+++ b/sys/dev/ic/isp_target.c   Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
--/* $NetBSD: isp_target.c,v 1.36 2021/08/21 11:55:25 andvar Exp $ */
+-/* $NetBSD: isp_target.c,v 1.37 2021/12/12 13:05:14 andvar Exp $ */
 /*-
  *  Copyright (c) 1997-2008 by Matthew Jacob
  *  All rights reserved.
@@ -65,7 +65,7 @@
 
 #ifdef __NetBSD__
 #include <sys/cdefs.h> 
-__KERNEL_RCSID(0, "$NetBSD: isp_target.c,v 1.36 2021/08/21 11:55:25 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: isp_target.c,v 1.37 2021/12/12 13:05:14 andvar Exp $");
 #include <dev/ic/isp_netbsd.h>
 #endif
 #ifdef __FreeBSD__
@@ -97,7 +97,7 @@
 
 /*
  * The Qlogic driver gets an interrupt to look at response queue entries.
- * Some of these are status completions for initiatior mode commands, but
+ * Some of these are status completions for initiator mode commands, but
  * if target mode is enabled, we get a whole wad of response queue entries
  * to be handled here.
  *
@@ -123,7 +123,7 @@
  * The third group that can show up in the response queue are Immediate
  * Notification events. These include things like notifications of SCSI bus
  * resets, or Bus Device Reset messages or other messages received. This
- * a classic oddbins area. It can get  a little weird because you then turn
+ * a classic oddbins area. It can get a little weird because you then turn
  * around and acknowledge the Immediate Notify by writing an entry onto the
  * request queue and then the f/w turns around and gives you an acknowledgement
  * to *your* acknowledgement on the response queue (the idea being to let
@@ -138,7 +138,7 @@
  *
  * Because of the way this driver is designed, unfortunately most of the
  * actual synchronization work has to be done in the platform specific
- * code- we have no synchroniation primitives in the common code.
+ * code- we have no synchronization primitives in the common code.
  */
 
 int
diff -r d323bbd451eb -r 875c577fb8c9 sys/dev/ic/isp_tpublic.h
--- a/sys/dev/ic/isp_tpublic.h  Sun Dec 12 11:18:46 2021 +0000
+++ b/sys/dev/ic/isp_tpublic.h  Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: isp_tpublic.h,v 1.20 2020/08/19 02:19:07 msaitoh Exp $ */
+/* $NetBSD: isp_tpublic.h,v 1.21 2021/12/12 13:05:14 andvar Exp $ */
 /*-
  *  Copyright (c) 1997-2008 by Matthew Jacob
  *  All rights reserved.
@@ -82,7 +82,7 @@
 /*
  * This structure is used to register to the outer layer the
  * binding of an HBA identifier, driver name and instance and the
- * lun width capapbilities of this inner layer. It's up to each
+ * lun width capabilities of this inner layer. It's up to each
  * platform to figure out how it wants to actually implement this.
  * A typical sequence would be for the MD layer to find some external
  * module's entry point and start by sending a QOUT_HBA_REG with info
@@ -260,7 +260,7 @@
  * must be inferred from the CDB.
  *
  * The tag cd_moved is the total amount of data moved so far. It is the
- * responsibilty of the inner layer to set this for every transaction and
+ * responsibility of the inner layer to set this for every transaction and
  * to keep track of it so that transport level residuals may be correctly
  * set.
  *
diff -r d323bbd451eb -r 875c577fb8c9 sys/dev/pci/if_bnxreg.h
--- a/sys/dev/pci/if_bnxreg.h   Sun Dec 12 11:18:46 2021 +0000
+++ b/sys/dev/pci/if_bnxreg.h   Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: if_bnxreg.h,v 1.27 2021/02/13 16:33:30 jakllsch Exp $  */
+/*     $NetBSD: if_bnxreg.h,v 1.28 2021/12/12 13:05:14 andvar Exp $    */
 /*     $OpenBSD: if_bnxreg.h,v 1.33 2009/09/05 16:02:28 claudio Exp $  */
 
 /*-
@@ -4634,7 +4634,7 @@
 #define MB_RX_CID_ADDR         BNX_MB_GET_CID_ADDR(RX_CID)
 
 /****************************************************************************/
-/* BNX Processor Firmwware Load Definitions                                */
+/* BNX Processor Firmware Load Definitions                                 */
 /****************************************************************************/
 
 struct cpu_reg {
diff -r d323bbd451eb -r 875c577fb8c9 sys/dev/sbus/bereg.h
--- a/sys/dev/sbus/bereg.h      Sun Dec 12 11:18:46 2021 +0000
+++ b/sys/dev/sbus/bereg.h      Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: bereg.h,v 1.9 2009/09/19 11:53:42 tsutsui Exp $        */
+/*     $NetBSD: bereg.h,v 1.10 2021/12/12 13:05:14 andvar Exp $        */
 
 /*-
  * Copyright (c) 1999 The NetBSD Foundation, Inc.
@@ -194,7 +194,7 @@
 #define BE_BR_RXCFG_ENABLE     0x00000001      /* enable the receiver */
 #define BE_BR_RXCFG_FIFO       0x0000000e      /* default rx fthresh */
 #define BE_BR_RXCFG_PSTRIP     0x00000020      /* pad byte strip enable */
-#define BE_BR_RXCFG_PMISC      0x00000040      /* enable promiscous mode */
+#define BE_BR_RXCFG_PMISC      0x00000040      /* enable promiscuous mode */
 #define BE_BR_RXCFG_DERR       0x00000080      /* disable error checking */
 #define BE_BR_RXCFG_DCRCS      0x00000100      /* disable crc stripping */
 #define BE_BR_RXCFG_ME         0x00000200      /* receive packets for me */
diff -r d323bbd451eb -r 875c577fb8c9 sys/net/if_slvar.h
--- a/sys/net/if_slvar.h        Sun Dec 12 11:18:46 2021 +0000
+++ b/sys/net/if_slvar.h        Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: if_slvar.h,v 1.34 2019/07/11 03:49:51 msaitoh Exp $    */
+/*     $NetBSD: if_slvar.h,v 1.35 2021/12/12 13:05:14 andvar Exp $     */
 
 /*-
  * Copyright (c) 1991, 1993
@@ -53,7 +53,7 @@
        u_int   sc_flags;               /* see below */
        u_int   sc_escape;      /* =1 if last char input was FRAME_ESCAPE */
        long    sc_lasttime;            /* last time a char arrived */
-       long    sc_abortcount;          /* number of abort esacpe chars */
+       long    sc_abortcount;          /* number of abort escape chars */
        long    sc_starttime;           /* time of first abort in window */
        long    sc_oqlen;               /* previous output queue size */
        long    sc_otimeout;            /* number of times output's stalled */
diff -r d323bbd451eb -r 875c577fb8c9 usr.bin/error/main.c
--- a/usr.bin/error/main.c      Sun Dec 12 11:18:46 2021 +0000
+++ b/usr.bin/error/main.c      Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: main.c,v 1.21 2011/08/17 13:11:22 christos Exp $       */
+/*     $NetBSD: main.c,v 1.22 2021/12/12 13:05:14 andvar Exp $ */
 
 /*
  * Copyright (c) 1980, 1993
@@ -39,7 +39,7 @@
 #if 0
 static char sccsid[] = "@(#)main.c     8.1 (Berkeley) 6/6/93";
 #endif
-__RCSID("$NetBSD: main.c,v 1.21 2011/08/17 13:11:22 christos Exp $");
+__RCSID("$NetBSD: main.c,v 1.22 2021/12/12 13:05:14 andvar Exp $");
 #endif /* not lint */
 
 #include <signal.h>
@@ -252,7 +252,7 @@
                }
        }
        /*
-        *      ed_agument's first argument is
+        *      ed_argument's first argument is
         *      a vi/ex compatible search argument
         *      to find the first occurrence of ###
         */



Home | Main Index | Thread Index | Old Index
diff -r d323bbd451eb -r 875c577fb8c9 sys/dev/ic/isp.c
--- a/sys/dev/ic/isp.c  Sun Dec 12 11:18:46 2021 +0000
+++ b/sys/dev/ic/isp.c  Sun Dec 12 13:05:13 2021 +0000
@@ -1,4 +1,4 @@
-/* $NetBSD: isp.c,v 1.134 2021/12/12 09:00:07 andvar Exp $ */
+/* $NetBSD: isp.c,v 1.135 2021/12/12 13:05:14 andvar Exp $ */
 /*
  * Machine and OS Independent (well, as best as possible)
  * code for the Qlogic ISP SCSI adapters.
@@ -43,7 +43,7 @@
  */
 #ifdef __NetBSD__
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: isp.c,v 1.134 2021/12/12 09:00:07 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: isp.c,v 1.135 2021/12/12 13:05:14 andvar Exp $");
 #include <dev/ic/isp_netbsd.h>
 #endif
 #ifdef __FreeBSD__
@@ -889,7 +889,7 @@
                         * three chunks. We loaded the first at the code_org
                         * address. The other two chunks, which follow right
                         * after each other in memory here, get loaded at
-                        * addresses specfied at offset 0x9..0xB.
+                        * addresses specified at offset 0x9..0xB.
                         */
 
                        nxtaddr = ptr[3];
@@ -3919,7 +3919,7 @@
                        break;
                } else if ((r & 0xffff) == MBOX_PORT_ID_USED) {
                        /*
-                        * If we get here, then the firmwware still thinks we're logged into this device, but with a different
+                        * If we get here, then the firmware still thinks we're logged into this device, but with a different
                         * handle. We need to break that association. We used to try and just substitute the handle, but then
                         * failed to get any data via isp_getpdb (below).
                         */
@@ -6709,7 +6709,7 @@
        ISPOPMAP(0xdf, 0xdf),   /* 0x51: DUMP RAM A64 */
        ISPOPMAP(0xdf, 0xff),   /* 0x52: INITIALIZE REQUEST QUEUE A64 */
        ISPOPMAP(0xef, 0xff),   /* 0x53: INITIALIZE RESPONSE QUEUE A64 */
-       ISPOPMAP(0xcf, 0x01),   /* 0x54: EXECUCUTE COMMAND IOCB A64 */
+       ISPOPMAP(0xcf, 0x01),   /* 0x54: EXECUTE COMMAND IOCB A64 */
        ISPOPMAP(0x07, 0x01),   /* 0x55: ENABLE TARGET MODE */
        ISPOPMAP(0x03, 0x0f),   /* 0x56: GET TARGET STATUS */
        ISPOPMAP(0x00, 0x00),   /* 0x57: */
@@ -6718,7 +6718,7 @@
        ISPOPMAP(0x03, 0x03),   /* 0x5a: SET DATA OVERRUN RECOVERY MODE */
        ISPOPMAP(0x01, 0x03),   /* 0x5b: GET DATA OVERRUN RECOVERY MODE */
        ISPOPMAP(0x0f, 0x0f),   /* 0x5c: SET HOST DATA */
-       ISPOPMAP(0x01, 0x01)    /* 0x5d: GET NOST DATA */
+       ISPOPMAP(0x01, 0x01)    /* 0x5d: GET HOST DATA */
 };
 
 static const char *scsi_mbcmd_names[] = {
@@ -6815,7 +6815,7 @@
        "SET DATA OVERRUN RECOVERY MODE",
        "GET DATA OVERRUN RECOVERY MODE",
        "SET HOST DATA",
-       "GET NOST DATA",
+       "GET HOST DATA",
 };
 
 static const uint32_t mbpfc[] = {